<?php
/**
* History:
*
* 1.0 - First version
* 1.1 - update, pagination
* 1.2 - update, sorting, search, translates
* 1.2.1 - modification css pagination, keep pagination length when we change the table or the display
* 1.2.2 - Fixed a security problem
*
*  @author    Vincent MASSON <contact@coeos.pro>
*  @copyright Vincent MASSON <www.coeos.pro>
*  @license   http://www.coeos.pro/fr/content/3-conditions-generales-de-ventes
*/

if (!defined('_PS_VERSION_'))
	exit;

class Affichertables extends Module
{
	/* @var boolean error */
	protected $error = false;

	public function __construct()
	{
		$this->name = 'affichertables';
		$this->tab = 'administration';
		$this->version = '1.2.2';
		$this->author = 'www.coeos.pro';

		parent::__construct();

		$this->displayName = $this->l('Display tables');
		$this->description = $this->l('Allow to display the tables SQL');
		$this->confirmUninstall = $this->l('Are you sure you want to delete this module ?');
	}
	public function install()
	{
		if (!parent::install() || !Configuration::updateValue('token_affichertables', md5(microtime())))
			return false;
		return true;
	}
	public function uninstall()
	{
		Configuration::deleteByName('token_affichertables');
		return true;
	}
	public function nbreLignesDefault()
	{
		return 100;
	}
	private function displayHelp()
	{
		$this->_html .= '
		<p style="float:right"><a href="http://www.coeos.pro/9-modules-prestashop"><img src="'.$this->_path.'/img/coeos_logo.jpg"/></a></p>
		<b>'.$this->l('This module allows you to display the database').'</b><br /><br />';
		$this->_html .= '<br /><br />MASSON Vincent<p><a href="http://www.coeos.pro/9-modules-prestashop">www.coeos.pro</a></p>
		<p><a href="mailto:contact@coeos.pro">contact@coeos.pro</a></p>';
	}

	public function getContent()
	{
		$this->_html = '<h2>'.$this->displayName.'</h2>';
		$this->context->controller->addJS(($this->_path).'js/jquery.datatable.js');
		$this->context->controller->addJS(($this->_path).'js/datatables.js');
		$this->displayHelp();
		$this->displayForm();
		return $this->_html;
	}

	private function displayForm()
	{
		$this->_html .= '
		<script type="text/javascript">
		function displayresult()
		{
			displayresults();
			showcolumns();
		}
		function displayresults()
		{
			var table = document.getElementById("tables").value;
			var codehtml = document.getElementById("codehtml").value;
			var pagination = document.getElementById("pagination").value;
			$.ajax({
			type: "POST",
			headers: { "cache-control": "no-cache" },
			url: "'._MODULE_DIR_.$this->name.'/ajax/results.php",
			data: 	{
					"table":table,
					"codehtml":codehtml,
					"token" : "'.Configuration::get('token_affichertables').'"
					},
			success: function(result)
			{
				document.getElementById("results").innerHTML = result;
				$(".displayTables").dataTable({
				paging: true,
				retrieve: true,
				searching: true,
				lengthChange: true,
				info: true,
				"stripeClasses": [ \'surligne\', \'\'],
				"display": "hover",
				"orderMulti": true,
				"orderClasses": true,
				 "lengthMenu": [[10, 50, 100, 500, -1], [10, 50, 100, 500, "'.$this->l('All').'"]],
				 
				"language": 
				{
					"paginate": 
					{
						"first": "|<<",
						"last": ">>|",
						"previous": "<",
						"next": ">"
					},
					"info" : "'.$this->l('Showing page').' _PAGE_ '.$this->l('of').' _PAGES_ <br/>'.
					$this->l('Records').' : _START_ à _END_ <br/>'.$this->l('Results display').' : _TOTAL_ / _MAX_",
					"infoFiltered" : "",
					"lengthMenu" : "'.$this->l('Number of records by page').' : _MENU_",
					"zeroRecords": "'.$this->l('No records to display').'",
					"sSearch": "'.$this->l('Search').' : ",
				},		 
				 
				"pagingType": "full_numbers",
				"pageLength": pagination
						});
			},
			error: function(result)
			{
				document.getElementById("results").innerHTML = "'.$this->l('Error, retry please...').'";
			}
			});
		}
		function showcolumns()
		{
			var table = document.getElementById("tables").value;
			$.ajax({
			type: "POST",
			headers: { "cache-control": "no-cache" },
			url: "'._MODULE_DIR_.$this->name.'/ajax/showcolumns.php",
			data: 	{
					"table" : table,
					"token" : "'.Configuration::get('token_affichertables').'"
					},
			success: function(result)
			{
				document.getElementById("infoshowcolumns").innerHTML = result;
			},
			error: function(result)
			{
				document.getElementById("infoshowcolumns").innerHTML = "'.$this->l('Error, retry please...').'";
			}
			});
		}
		</script>			
	 	<fieldset style="background-color:#f4f8fb">
		<legend style="background-color:#f4f8fb"><img src="'.$this->_path.'logo.gif" alt="" title="" /> '.$this->l('Select table').'</legend>
		<form method="post" action="'.$_SERVER['REQUEST_URI'].'">					
			<input type="hidden" id="pageencours" name="pageencours" value="0"/>
			<label>'.$this->l('Table').' : </label>
			<div class="margin-form">
			<select name="table" id="tables" onchange="displayresult()">';
		if ($tables = Db::getInstance()->ExecuteS('SHOW TABLES FROM `'._DB_NAME_.'` LIKE "'._DB_PREFIX_.'%"'))
			foreach ($tables as $table)
			{
				$nb = (int)Db::getInstance()->getValue('SELECT COUNT(*) FROM '.$table['Tables_in_'._DB_NAME_.' ('._DB_PREFIX_.'%)']);
				$this->_html .= '<option value="'.$table['Tables_in_'._DB_NAME_.' ('._DB_PREFIX_.'%)'].'">
				'.$table['Tables_in_'._DB_NAME_.' ('._DB_PREFIX_.'%)'].' ('.$nb.')</option>';
			}

		$this->_html .= '</select>
			</div>
			<label>'.$this->l('Viewing').' : </label>
			<div class="margin-form">
			<select id="codehtml" name="codehtml" onchange="displayresults()">
				<option value="0">standard</option>
				<option value="1">htmlentities</option>
				<option value="2">htmlentities + pre</option>
			</select>
			</div>
		</form>
		<div id="results"><input type="hidden" id="pagination" value="'.$this->nbreLignesDefault().'"></div>
		<div id="infoshowcolumns"></div>
		</fieldset>
		<style type="text/css">
			table.displayTables td, table.displayTables th, table#infosSQL td, table#infosSQL th{border:1px solid black;padding:10px;}
			table#infosSQL td, table#infosSQL th{padding:5px;}
			table.displayTables {border-collapse:collapse;width:100%}
			table#infosSQL{border-collapse:collapse;}
			table.displayTables tr.bg{background-color:#FFF6D3}
			table.displayTables td.gras{font-weight:bold;font-size:130%;text-align:center;}
			.dataTables_paginate a{margin-right:10px;border:1px solid #000;padding:8px 5px;text-decoration:none;
				border-radius: 3px;display: inline-block;width:25px}
			.dataTables_paginate a:last-child{margin-right:0}
			.pagination{font-size:150%}
			.dataTables_paginate {bottom: 10px;margin-bottom: 0;position: fixed;right: 10px;background-color: #F4F8FB;
				border-radius: 5px;z-index: 1000;border: 1px solid #c0c0c0;padding: 2px 6px 2px 2px;opacity: 0.5;}
			.dataTables_paginate:hover{opacity: 1;background-color:white}
			.plagepage{font-weight:normal;font-size:80%}
			.surligne{background-color:#FFF6D3}
			table.displayTables thead .sorting_desc{background: url("'.$this->_path.'/img/sort_desc.png") no-repeat center right;}
			table.displayTables thead .sorting_asc{background: url("'.$this->_path.'/img/sort_asc.png") no-repeat center right;}
			table.displayTables thead .sorting{background: url("'.$this->_path.'/img/sort_both.png") no-repeat center right;}
			.displayTables tbody tr:first-child td {border-top:none !important;}
			a.paginate_button {margin:5px;text-align:center}
			.dataTables_paginate  a.current{font-weight: bold;color: red;}
			a.paginate_button:hover {font-weight:bold;background-color: #cfc;}
			#results label{display:block;width: 308px;float:none}
			.dataTables_length, .dataTables_filter {padding-bottom: 1em;}
			input[type="search"] {width: 100px;}
			#results .dataTables_filter label{width: 363px}
		</style><br/><br/>';
		$this->l('Informations on the table');
	}

}